<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nn_NO">
<context>
    <name>GuidelineEditDialog</name>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="14"/>
        <source>Edit guideline...</source>
        <translation>Rediger hjelpelinje&#xa0;…</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="22"/>
        <source>Page:</source>
        <translation>Side:</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="36"/>
        <source>Position:</source>
        <translation>Posisjon:</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="53"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="58"/>
        <source>in</source>
        <translation>tommar</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="63"/>
        <source>bp</source>
        <translation>bp</translation>
    </message>
</context>
<context>
    <name>PaperSize</name>
    <message>
        <location filename="../src/PaperSizes.cpp" line="24"/>
        <source>Beamer 16:10</source>
        <translation>Beamer 16:10</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="25"/>
        <source>Beamer 16:9</source>
        <translation>Beamer 16:9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="26"/>
        <source>Beamer 14:9</source>
        <translation>Beamer 14:9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="27"/>
        <source>Beamer 1.41:1</source>
        <translation>Beamer 1,41:1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="28"/>
        <source>Beamer 5:4</source>
        <translation>Beamer 5:4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="29"/>
        <source>Beamer 4:3</source>
        <translation>Beamer 4:3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="30"/>
        <source>Beamer 3:2</source>
        <translation>Beamer 3:2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="33"/>
        <source>Screen</source>
        <translation>Screen</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="36"/>
        <source>DIN 4A0</source>
        <translation>4A0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="37"/>
        <source>DIN 2A0</source>
        <translation>2A0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="38"/>
        <source>DIN A0</source>
        <translation>A0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="39"/>
        <source>DIN A1</source>
        <translation>A1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="40"/>
        <source>DIN A2</source>
        <translation>A2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="41"/>
        <source>DIN A3</source>
        <translation>A3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="42"/>
        <source>DIN A4</source>
        <translation>A4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="43"/>
        <source>DIN A5</source>
        <translation>A5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="44"/>
        <source>DIN A6</source>
        <translation>A6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="45"/>
        <source>DIN A7</source>
        <translation>A7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="46"/>
        <source>DIN A8</source>
        <translation>A8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="47"/>
        <source>DIN A9</source>
        <translation>A9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="48"/>
        <source>DIN A10</source>
        <translation>A10</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="49"/>
        <source>DIN B0</source>
        <translation>B0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="50"/>
        <source>DIN B1</source>
        <translation>B1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="51"/>
        <source>DIN B2</source>
        <translation>B2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="52"/>
        <source>DIN B3</source>
        <translation>B3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="53"/>
        <source>DIN B4</source>
        <translation>B4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="54"/>
        <source>DIN B5</source>
        <translation>B5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="55"/>
        <source>DIN B6</source>
        <translation>B6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="56"/>
        <source>DIN B7</source>
        <translation>B7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="57"/>
        <source>DIN B8</source>
        <translation>B8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="58"/>
        <source>DIN B9</source>
        <translation>B9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="59"/>
        <source>DIN B10</source>
        <translation>B10</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="60"/>
        <source>DIN C0</source>
        <translation>C0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="61"/>
        <source>DIN C1</source>
        <translation>C1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="62"/>
        <source>DIN C2</source>
        <translation>C2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="63"/>
        <source>DIN C3</source>
        <translation>C3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="64"/>
        <source>DIN C4</source>
        <translation>C4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="65"/>
        <source>DIN C5</source>
        <translation>C5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="66"/>
        <source>DIN C6</source>
        <translation>C6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="67"/>
        <source>DIN C7</source>
        <translation>C7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="68"/>
        <source>DIN C8</source>
        <translation>C8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="69"/>
        <source>DIN C9</source>
        <translation>C9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="70"/>
        <source>DIN C10</source>
        <translation>C10</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="71"/>
        <source>DIN DL</source>
        <translation>DL</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="72"/>
        <source>DIN DLE</source>
        <translation>DLE</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="73"/>
        <source>DIN C6/C5</source>
        <translation>C6/C5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="74"/>
        <source>DIN RA0</source>
        <translation>RA0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="75"/>
        <source>DIN RA1</source>
        <translation>RA1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="76"/>
        <source>DIN RA2</source>
        <translation>RA2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="77"/>
        <source>DIN RA3</source>
        <translation>RA3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="78"/>
        <source>DIN RA4</source>
        <translation>RA4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="79"/>
        <source>DIN SRA0</source>
        <translation>SRA0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="80"/>
        <source>DIN SRA1</source>
        <translation>SRA1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="81"/>
        <source>DIN SRA2</source>
        <translation>SRA2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="82"/>
        <source>DIN SRA3</source>
        <translation>SRA3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="83"/>
        <source>DIN SRA4</source>
        <translation>SRA4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="84"/>
        <source>SIS D0</source>
        <translation>SIS D0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="85"/>
        <source>SIS D1</source>
        <translation>SIS D1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="86"/>
        <source>SIS D2</source>
        <translation>SIS D2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="87"/>
        <source>SIS D3</source>
        <translation>SIS D3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="88"/>
        <source>SIS D4</source>
        <translation>SIS D4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="89"/>
        <source>SIS D5</source>
        <translation>SIS D5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="90"/>
        <source>SIS D6</source>
        <translation>SIS D6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="91"/>
        <source>SIS D7</source>
        <translation>SIS D7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="92"/>
        <source>SIS D8</source>
        <translation>SIS D8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="93"/>
        <source>SIS D9</source>
        <translation>SIS D9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="94"/>
        <source>SIS E0</source>
        <translation>SIS E0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="95"/>
        <source>SIS E1</source>
        <translation>SIS E1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="96"/>
        <source>SIS E2</source>
        <translation>SIS E2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="97"/>
        <source>SIS E3</source>
        <translation>SIS E3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="98"/>
        <source>SIS E4</source>
        <translation>SIS E4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="99"/>
        <source>SIS E5</source>
        <translation>SIS E5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="100"/>
        <source>SIS E6</source>
        <translation>SIS E6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="101"/>
        <source>SIS E7</source>
        <translation>SIS E7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="102"/>
        <source>SIS E8</source>
        <translation>SIS E8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="103"/>
        <source>SIS E9</source>
        <translation>SIS E9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="104"/>
        <source>SIS F0</source>
        <translation>SIS F0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="105"/>
        <source>SIS F1</source>
        <translation>SIS F1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="106"/>
        <source>SIS F2</source>
        <translation>SIS F2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="107"/>
        <source>SIS F3</source>
        <translation>SIS F3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="108"/>
        <source>SIS F4</source>
        <translation>SIS F4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="109"/>
        <source>SIS F5</source>
        <translation>SIS F5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="110"/>
        <source>SIS F6</source>
        <translation>SIS F6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="111"/>
        <source>SIS F7</source>
        <translation>SIS F7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="112"/>
        <source>SIS F8</source>
        <translation>SIS F8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="113"/>
        <source>SIS F9</source>
        <translation>SIS F9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="114"/>
        <source>SIS G0</source>
        <translation>SIS G0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="115"/>
        <source>SIS G1</source>
        <translation>SIS G1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="116"/>
        <source>SIS G2</source>
        <translation>SIS G2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="117"/>
        <source>SIS G3</source>
        <translation>SIS G3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="118"/>
        <source>SIS G4</source>
        <translation>SIS G4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="119"/>
        <source>SIS G5</source>
        <translation>SIS G5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="120"/>
        <source>SIS G6</source>
        <translation>SIS G6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="121"/>
        <source>SIS G7</source>
        <translation>SIS G7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="122"/>
        <source>SIS G8</source>
        <translation>SIS G8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="123"/>
        <source>SIS G9</source>
        <translation>SIS G9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="124"/>
        <source>JIS B0</source>
        <translation>JIS B0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="125"/>
        <source>JIS B1</source>
        <translation>JIS B1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="126"/>
        <source>JIS B2</source>
        <translation>JIS B2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="127"/>
        <source>JIS B3</source>
        <translation>JIS B3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="128"/>
        <source>JIS B4</source>
        <translation>JIS B4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="129"/>
        <source>JIS B5</source>
        <translation>JIS B5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="130"/>
        <source>JIS B6</source>
        <translation>JIS B6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="131"/>
        <source>JIS B7</source>
        <translation>JIS B7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="132"/>
        <source>JIS B8</source>
        <translation>JIS B8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="133"/>
        <source>JIS B9</source>
        <translation>JIS B9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="134"/>
        <source>JIS B10</source>
        <translation>JIS B10</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="135"/>
        <source>JIS B11</source>
        <translation>JIS B11</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="136"/>
        <source>JIS B12</source>
        <translation>JIS B12</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="137"/>
        <source>JIS Shiroku ban 4</source>
        <translation>JIS Shiroku ban 4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="138"/>
        <source>JIS Shiroku ban 5</source>
        <translation>JIS Shiroku ban 5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="139"/>
        <source>JIS Shiroku ban 6</source>
        <translation>JIS Shiroku ban 6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="140"/>
        <source>JIS Kiku 4</source>
        <translation>JIS Kiku 4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="141"/>
        <source>JIS Kiku 5</source>
        <translation>JIS Kiku 5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="142"/>
        <source>SAC D0</source>
        <translation>SAC D0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="143"/>
        <source>SAC D1</source>
        <translation>SAC D1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="144"/>
        <source>SAC D2</source>
        <translation>SAC D2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="145"/>
        <source>SAC D3</source>
        <translation>SAC D3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="146"/>
        <source>SAC D4</source>
        <translation>SAC D4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="147"/>
        <source>SAC D5</source>
        <translation>SAC D5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="148"/>
        <source>SAC D6</source>
        <translation>SAC D6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="150"/>
        <source>Letter (ANSI A)</source>
        <translatorcomment>skip-rule: unormert
</translatorcomment>
        <translation>Letter (ANSI A)</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="151"/>
        <source>Legal</source>
        <translation>Legal</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="152"/>
        <source>Tabloid (ANSI B)</source>
        <translation>Tabloid (ANSI B)</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="153"/>
        <source>Ledger</source>
        <translation>Ledger</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="154"/>
        <source>Junior Legal</source>
        <translation>Junior Legal</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="155"/>
        <source>Half Letter</source>
        <translatorcomment>skip-rule: unormert
</translatorcomment>
        <translation>Half Letter</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="156"/>
        <source>Government Letter</source>
        <translatorcomment>skip-rule: unormert
</translatorcomment>
        <translation>Government Letter</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="157"/>
        <source>Government Legal</source>
        <translation>Government Legal</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="158"/>
        <source>ANSI C</source>
        <translation>ANSI C</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="159"/>
        <source>ANSI D</source>
        <translation>ANSI D</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="160"/>
        <source>ANSI E</source>
        <translation>ANSI E</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="161"/>
        <source>Arch A</source>
        <translation>Arch A</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="162"/>
        <source>Arch B</source>
        <translation>Arch B</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="163"/>
        <source>Arch C</source>
        <translation>Arch C</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="164"/>
        <source>Arch D</source>
        <translation>Arch D</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="165"/>
        <source>Arch E1</source>
        <translation>Arch E1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="166"/>
        <source>Arch E</source>
        <translation>Arch E</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="167"/>
        <source>Arch E2</source>
        <translation>Arch E2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="168"/>
        <source>Arch E3</source>
        <translation>Arch E3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="201"/>
        <source>mm</source>
        <extracomment>Length unit: millimeters</extracomment>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="207"/>
        <source>in</source>
        <extracomment>Length unit: inches</extracomment>
        <translation>tommar</translation>
    </message>
</context>
<context>
    <name>QtPDF</name>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="33"/>
        <source>[language name]</source>
        <translation>Norsk (nynorsk)</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="34"/>
        <source>[translator&apos;s name/email]</source>
        <translation>Karl Ove Hufthammer &lt;karl@huftis.org&gt;</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentScene</name>
    <message>
        <location filename="../src/PDFBackend.cpp" line="612"/>
        <source>rendering page</source>
        <translation>teiknar opp side</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
        <source>Unlock PDF</source>
        <translation>Lås opp PDF</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
        <source>Please enter the password to unlock the PDF</source>
        <translation>Skriv inn passordet for å låsa opp PDF-en</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2045"/>
        <source>Incorrect password</source>
        <translation>Feil passord</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2045"/>
        <source>The password you entered was incorrect.</source>
        <translation>Du skreiv inn feil passord.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2051"/>
        <source>This document is locked. You need a password to open it.</source>
        <translation>Dokumentet er låst. Du treng eit passord for å opna det.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2052"/>
        <source>Unlock</source>
        <translation>Lås opp</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentView</name>
    <message>
        <location filename="../src/PDFDocumentTools.cpp" line="976"/>
        <source>Insufficient permission</source>
        <translation>Manglar løyve</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentTools.cpp" line="976"/>
        <source>Text extraction is not allowed for this document.</source>
        <translation>Uthenting av tekst er ikkje tillate for dette dokumentet.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2597"/>
        <source>Goto page %1</source>
        <translation>Gå til side %1</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2609"/>
        <source>Execute `%1`</source>
        <translation>Køyr «%1»</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2855"/>
        <location filename="../src/PDFDocumentView.cpp" line="2872"/>
        <source>Table of Contents</source>
        <translation>Innhaldsliste</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2964"/>
        <location filename="../src/PDFDocumentView.cpp" line="3171"/>
        <source>Meta Data</source>
        <translation>Metadata</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3020"/>
        <location filename="../src/PDFDocumentView.cpp" line="3181"/>
        <source>Processing</source>
        <translation>Handsamar</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3052"/>
        <location filename="../src/PDFDocumentView.cpp" line="3188"/>
        <source>Other</source>
        <translation>Anna</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3115"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3118"/>
        <source>No</source>
        <translation>Nei</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3121"/>
        <location filename="../src/PDFDocumentView.cpp" line="3158"/>
        <source>Unknown</source>
        <translation>Ukjend</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3173"/>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3174"/>
        <source>Title:</source>
        <translation>Tittel:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3175"/>
        <source>Author:</source>
        <translation>Forfattar:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3176"/>
        <source>Subject:</source>
        <translation>Emne:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3177"/>
        <source>Keywords:</source>
        <translation>Nøkkelord:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3182"/>
        <source>Creator:</source>
        <translation>Opphavsprogram:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3183"/>
        <source>Producer:</source>
        <translation>Produsent:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3184"/>
        <source>Creation date:</source>
        <translation>Oppretta:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3185"/>
        <source>Modification date:</source>
        <translation>Sist endra:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3186"/>
        <source>Trapped:</source>
        <translation>Fanga:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3197"/>
        <location filename="../src/PDFDocumentView.cpp" line="3291"/>
        <source>Fonts</source>
        <translation>Skrifter</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3247"/>
        <source>Type 0</source>
        <translation>Type 0</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3250"/>
        <source>Type 1</source>
        <translation>Type 1</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3253"/>
        <source>Type 1 (multiple master)</source>
        <translation>Type 1 (Multiple Master)</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3256"/>
        <source>Type 3</source>
        <translation>Type 3</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3259"/>
        <source>TrueType</source>
        <translation>TrueType</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3262"/>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3262"/>
        <source>no</source>
        <translation>nei</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3265"/>
        <source>[embedded]</source>
        <translation>[innebygd]</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3268"/>
        <source>[builtin]</source>
        <translation>[systemskrift]</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3292"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3292"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3292"/>
        <source>Subset</source>
        <translation>Delmengd</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3292"/>
        <source>Source</source>
        <translation>Kjelde</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3300"/>
        <location filename="../src/PDFDocumentView.cpp" line="3395"/>
        <source>Permissions</source>
        <translation>Løyve</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3349"/>
        <location filename="../src/PDFDocumentView.cpp" line="3358"/>
        <location filename="../src/PDFDocumentView.cpp" line="3367"/>
        <location filename="../src/PDFDocumentView.cpp" line="3374"/>
        <location filename="../src/PDFDocumentView.cpp" line="3379"/>
        <source>Allowed</source>
        <translation>Tillate</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3351"/>
        <source>Low resolution only</source>
        <translation>Berre låg oppløysing</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3354"/>
        <location filename="../src/PDFDocumentView.cpp" line="3364"/>
        <location filename="../src/PDFDocumentView.cpp" line="3371"/>
        <location filename="../src/PDFDocumentView.cpp" line="3376"/>
        <location filename="../src/PDFDocumentView.cpp" line="3381"/>
        <location filename="../src/PDFDocumentView.cpp" line="3386"/>
        <location filename="../src/PDFDocumentView.cpp" line="3387"/>
        <location filename="../src/PDFDocumentView.cpp" line="3388"/>
        <location filename="../src/PDFDocumentView.cpp" line="3389"/>
        <location filename="../src/PDFDocumentView.cpp" line="3390"/>
        <source>Denied</source>
        <translation>Nekta</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3360"/>
        <source>Assembling only</source>
        <translation>Berre samansetjing</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3361"/>
        <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
        <translation>Set inn, roter eller slett sider og lag bokmerke eller miniatyrbilete av sider</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3369"/>
        <source>Accessibility support only</source>
        <translation>Berre tilgjengestøtte</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3397"/>
        <source>Printing:</source>
        <translation>Utskrift:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3398"/>
        <source>Modifications:</source>
        <translation>Endringar:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3399"/>
        <source>Extraction:</source>
        <translation>Tekstuthenting:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3400"/>
        <source>Annotation:</source>
        <translation>Merknadar:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3401"/>
        <source>Filling forms:</source>
        <translation>Skjemautfylling:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3409"/>
        <location filename="../src/PDFDocumentView.cpp" line="3501"/>
        <source>Annotations</source>
        <translation>Merknadar</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3502"/>
        <source>Page</source>
        <translation>Side</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3502"/>
        <source>Subject</source>
        <translation>Emne</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3502"/>
        <source>Author</source>
        <translation>Forfattar</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3502"/>
        <source>Contents</source>
        <translation>Innhald</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3077"/>
        <source>B</source>
        <extracomment>File size: bytes</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3079"/>
        <source>kB</source>
        <extracomment>File size: kilobytes</extracomment>
        <translatorcomment>Har sjekka at det er snakk om 1 000 byte.
</translatorcomment>
        <translation>kB</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3081"/>
        <source>MB</source>
        <extracomment>File size: megabytes</extracomment>
        <translatorcomment>skip-rule: einingmb
Har sjekka at det er snakk om 1 000² byte.
</translatorcomment>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3083"/>
        <source>GB</source>
        <extracomment>File size: gigabytes</extracomment>
        <translatorcomment>Har sjekka at det er snakk om 1 000³ byte.
</translatorcomment>
        <translation>GB</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3085"/>
        <source>TB</source>
        <extracomment>File size: terabytes</extracomment>
        <translatorcomment>Har sjekka at det er snakk om 1 000⁴ byte.
</translatorcomment>
        <translation>TB</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3178"/>
        <source>Page size:</source>
        <translation>Sidestorleik:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3179"/>
        <source>File size:</source>
        <translation>Filstorleik:</translation>
    </message>
</context>
</TS>
